@@ -49,6 +49,7 @@ _httpx_request = None
 CLIENT_ID = "iYCeC9g08h5vuP9UqvPHKKSVrKFXGa1v"
 CLIENT_SECRET = "jXiFMOPVPCWlO2M5CwWQzffpNPaGTRBG"
 ED2K_NAME_TRANSTAB: Final = dict(zip(b"/|", ("%2F", "%7C")))
+OCR = DdddOcr().classification
 
 
 def convert_digest(digest, /):
@@ -2088,7 +2089,7 @@ class DuPanShareList(HTTPXClientMixin):
         self, 
         /, 
         min_confirm: int = 2, 
-        ocr: Callable[[bytes], str] = DdddOcr(beta=True, show_ad=False).classification, 
+        ocr: Callable[[bytes], str] = OCR, 
         *, 
         async_: Literal[False] = False, 
         **request_kwargs
@@ -2099,7 +2100,7 @@ class DuPanShareList(HTTPXClientMixin):
         self, 
         /, 
         min_confirm: int = 2, 
-        ocr: Callable[[bytes], str] = DdddOcr(beta=True, show_ad=False).classification, 
+        ocr: Callable[[bytes], str] = OCR,  
         *, 
         async_: Literal[True], 
         **request_kwargs
@@ -2109,7 +2110,7 @@ class DuPanShareList(HTTPXClientMixin):
         self, 
         /, 
         min_confirm: int = 2, 
-        ocr: Callable[[bytes], str] = DdddOcr(beta=True, show_ad=False).classification, 
+        ocr: Callable[[bytes], str] = OCR, 
         *, 
         async_: Literal[False, True] = False, 
         **request_kwargs
